==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>点击托盘图标
或再次按下录屏快捷键停止录制</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>截图录屏</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>保存失败。请保存在当前用户目录下。</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>截图完成</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>选择区域</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>图片已保存到%1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>正在保存录屏文件，请稍候...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>因在录制过程中关闭了窗口特效，录屏已结束</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>录制完毕</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>文件已保存到%1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>截图录屏将在%1秒后启动</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>在此处添加文本</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>启动/截图 </translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>退出/保存</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>绘图</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>调整区域</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>快速启动截图</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>光标所在窗口截图</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>延时5秒截屏</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>截取全屏</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直线</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>画笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除选中图形</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>向上扩大选区高度</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>向下扩大选区高度</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>向左扩大选区宽度</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>向右扩大选区宽度</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>向上缩小选区高度</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>向下缩小选区高度</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>向左缩小选区宽度</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>向右缩小选区宽度</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>录音</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>按键</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>快速启动录屏</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>启动/录屏</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>录制鼠标</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>模糊</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>马赛克</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>录音开启</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>麦克风</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>系统音频</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>录音关闭</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>显示按键</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>隐藏按键</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>开启摄像头</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>关闭摄像头</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>显示点击</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>格式：</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>帧数：</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直线</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>箭头</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>画笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>指定位置</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>显示光标</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>录制鼠标</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>显示光标</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> 调整录制区域范围在%1*%2以内，视频效果更佳</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>录音</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>点击托盘图标
或再次按下录屏快捷键停止录制</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>屏幕录制中请勿旋转屏幕</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>截图录屏</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>保存失败。请保存在当前用户目录下。</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>截图完成</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>选择区域</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>图片已保存到%1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>正在保存录屏文件，请稍候...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>因在录制过程中关闭了窗口特效，录屏已结束</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>截图文件已保存到相册</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>截图失败。</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滚动截图</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>录制完毕</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>文件已保存到%1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>截图录屏将在%1秒后启动</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>查看帮助</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>无法继续截图，</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>已到滚动区域底部</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>已到最大长度</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>调整捕捉区域</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>滚动鼠标滚轮或单击捕捉区域</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>请放慢滚动速度</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>无效区域，点击</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>在此处添加文本</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>启动/截图 </translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>退出/保存</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>调整区域</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>快速启动截图</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>光标所在窗口截图</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>延时5秒截屏</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>截取全屏</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直线</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>画笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除选中图形</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>向上扩大选区高度</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>向下扩大选区高度</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>向左扩大选区宽度</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>向右扩大选区宽度</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>向上缩小选区高度</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>向下缩小选区高度</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>向左缩小选区宽度</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>向右缩小选区宽度</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>录音</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>按键</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>快速启动录屏</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>启动/录屏</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>录制鼠标</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>识别文字</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滚动截图</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>贴图</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>模糊</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>马赛克</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>录音开启</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>麦克风</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>系统音频</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>录音关闭</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>显示按键</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>隐藏按键</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>开启摄像头</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>关闭摄像头</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>显示点击</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>格式：</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>帧数：</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直线</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>箭头</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>画笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>指定位置</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>显示光标</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>录制鼠标</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>显示光标</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>识别文字</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滚动截图</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>贴图</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> 调整录制区域范围在%1*%2以内，视频效果更佳</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>录屏功能暂不可用</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
</TS>
